# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`fail2ban`](#fail2ban): Manage fail2ban and its configuration to jam bruteforce attempts on
services running on a computer.
* [`fail2ban::params`](#fail2banparams): Default values for params of the main class

_Private Classes_

* `fail2ban::config`: Configure fail2ban service
* `fail2ban::install`: Install fail2ban
* `fail2ban::service`: Enable fail2ban daemon

**Defined types**

* [`fail2ban::filter`](#fail2banfilter): Setup a filter for fail2ban
* [`fail2ban::jail`](#fail2banjail): Setup a fail2ban jail to reduce effectiveness of bruteforce.

## Classes

### fail2ban

fail2ban/manifests/init.pp

- Copyright (C) 2007 admin@immerda.ch
- Copyright (C) 2014-2018 gabster@lelutin.ca

* **Note** `blocktype` is not offered as a global option since it's not a great
idea to set a globally used default value for this option. It's used
differently by all actions and different values are expected from each
action, so it's generally recommended to override this for each action
individually by creating a `.local` file in `actions.d`.

* **See also**
https://github.com/fail2ban/fail2ban/blob/0.11/man/jail.conf.5
jail.conf(5)

#### Examples

##### basic usage

```puppet
class { 'fail2ban: }
```

##### ignore localhost and another non-routable IP

```puppet
class { 'fail2ban':
  ignoreip => ['127.0.0.1', '10.0.0.1'],
}
```

#### Parameters

The following parameters are available in the `fail2ban` class.

##### `rm_fail2ban_local`

Data type: `Boolean`

Force removal of file /etc/fail2ban/fail2ban.local if present.

Default value: `true`

##### `rm_jail_local`

Data type: `Boolean`

Force removal of file /etc/fail2ban/jail.local if present.

Default value: `true`

##### `purge_fail2ban_dot_d`

Data type: `Boolean`

Remove all unmanaged files in /etc/fail2ban/fail2ban.d/

Default value: `true`

##### `purge_jail_dot_d`

Data type: `Boolean`

Remove all unmanaged files in /etc/fail2ban/jail.d/

Default value: `true`

##### `persistent_bans`

Data type: `Boolean`

Write out banned IPs to a file on teardown and restore bans when starting
fail2ban back up. This option is deprecated and is bound to be removed in
puppet-fail2ban 4.0

Default value: `false`

##### `config_file_mode`

Data type: `String`

File mode set on all fail2ban configuration files managed by this module.

Default value: '0644'

##### `loglvl`

Data type: `Fail2ban::Loglevel`

Set fail2ban's loglevel.

Default value: 'INFO'

##### `logtarget`

Data type: `String`

Define where fail2ban's logs are sent.

Default value: '/var/log/fail2ban.log'

##### `syslogsocket`

Data type: `String`

Path to syslog's socket file, or "auto" for automatically discovering it.

Default value: 'auto'

##### `socket`

Data type: `String`

Path to fail2ban's own socket file. This file is used by fail2ban-client to
communicate with the daemon.

Default value: '/var/run/fail2ban/fail2ban.sock'

##### `pidfile`

Data type: `String`

Path to fail2ban's pid file. This usually needs to be in a place where the
init script or systemd unit file can find it.

Default value: '/var/run/fail2ban/fail2ban.pid'

##### `dbfile`

Data type: `String`

Path to fail2ban's database file.

Default value: '/var/lib/fail2ban/fail2ban.sqlite3'

##### `dbpurgeage`

Data type: `Integer`

Age of entries in fail2ban's database that get removed when performing a
database purge operation.

Default value: 86400

##### `enabled`

Data type: `Boolean`

Whether or not to enable jails by default. fail2ban's man page recommends
to keep this to false, but by default the module purges jail.d of unknown
files so it might be safe to set to true in order to avoid repeating this
setting on all jails. If you set purge_jail_dot_d to false, it might be
wiser to keep this to false in order to avoid enabling jails that get
dropped in jail.d.

Default value: `false`

##### `filter`

Data type: `String`

Default name of filter to use for jails.

Default value: '%(__name__)s'

##### `ignoreip`

Data type: `Array[String, 0]`

Default list of IPs or CIDR prefixes that should not get banned.

Default value: ['127.0.0.1']

##### `bantime`

Data type: `Integer`

Default duration in number of seconds to ban an IP address for.

Default value: 600

##### `findtime`

Data type: `Integer`

Default interval during which to count occurences of an IP.

Default value: 600

##### `maxretry`

Data type: `Integer`

Default number of times an IP should be detectd by a filter during findtime
for it to get banned.

Default value: 3

##### `ignorecommand`

Data type: `String`

Default command used to determine if an IP should be exempted from being
banned.

Default value: ''

##### `backend`

Data type: `Fail2ban::Backend`

Default method used to get information from logs.

Default value: 'auto'

##### `destemail`

Data type: `String`

Default email address used as recipient by actions that send out emails.

Default value: 'root@localhost'

##### `sender`

Data type: `String`

Default email address set as sender by actions that send out emails.

Default value: 'root@localhost'

##### `fail2ban_agent`

Data type: `String`

User-agent sent on HTTP requests that are made by some actions.

Default value: 'Fail2Ban/%(fail2ban_version)s'

##### `banaction`

Data type: `String`

Default action name extrapolated when defining some of the default actions.

Default value: 'iptables-multiport'

##### `banaction_allports`

Data type: `String`

Default action name that can be extrapolated when defining some of the
default actions. This one is meant to ban all ports at once instead of
specific ones.

Default value: 'iptables-allports'

##### `chain`

Data type: `String`

Default name of the iptables chain used by iptables-based actions.

Default value: 'INPUT'

##### `port`

Data type: `Fail2ban::Port`

Default comma separated list of ports, port names or port ranges used by
actions when banning an IP.

Default value: '0:65535'

##### `mta`

Data type: `String`

Default program name used for sending out email by actions that do so.

Default value: 'sendmail'

##### `protocol`

Data type: `Fail2ban::Protocol`

Default protocol name used by actions.

Default value: 'tcp'

##### `action`

Data type: `String`

Default action that gets called when an IP triggers maxretry number of
times a filter within findtime.

Default value: '%(action_)s'

##### `usedns`

Data type: `Fail2ban::Usedns`

Default behaviour whether or not to resolve IPs when they are found in a
log by a filter.

Default value: 'warn'

##### `logpath`

Data type: `Optional[String]`

Default path to log file being used by jails. This value is usually not set
and logpath is defined for each jail for more clarity.

Default value: `undef`

##### `logencoding`

Data type: `String`

Name of the encoding of log files. If set to "auto", fail2ban will use what
is set in the system's locale setting.

Default value: 'auto'

##### `failregex`

Data type: `Optional[String]`

Regular expressions to add to all filters' failregex. This is usually not
used.

Default value: `undef`

##### `ignoreregex`

Data type: `Optional[String]`

Regular expressions to add to all filters' ignoreregex. This is usually not
used but could be useful to have something excluded from bans everywhere.

Default value: `undef`

##### `fail2ban_conf_template`

Data type: `String[1]`



Default value: 'fail2ban/fail2ban.conf.erb'

##### `jail_conf_template`

Data type: `String[1]`



Default value: $fail2ban::params::jail_conf_template

### fail2ban::params

fail2ban::params

## Defined types

### fail2ban::filter

fail2ban/manifests/filter.pp

- Copyright (C) 2014-2018 gabster@lelutin.ca

Filters are how fail2ban detects mischief in logs. They contain regular
expressions that should catch bad activity and identify the IP that is doing
this activity.

#### Examples

##### defining filter for jenkins

```puppet
fail2ban::filter { 'jenkins':
  failregexes => [
    # Those regexes are really arbitrary examples.
    'Invalid login to Jenkins by user mooh by IP \'<HOST>\'',
    'Forced entry trial by <HOST>',
  ],
}
```

#### Parameters

The following parameters are available in the `fail2ban::filter` defined type.

##### `failregexes`

Data type: `Array[String, 1]`

List of regular expressions that will be run against new log lines as they
reach fail2ban. The regular expressions follow the Python regular
expression format, and there are some special patterns that fail2ban can
use. See the jail.conf(5) man page for more details. Each item in the list
is placed on its own line. Lines starting with the second one are prepended
with spaces so that the regular expressions line up with the beginning of
the first one.

##### `ensure`

Data type: `Enum['present', 'absent']`

Whether the resources should be installed or removed.

Default value: 'present'

##### `config_file_mode`

Data type: `String`

Permission mode given to the filter file created by this defined type.

Default value: '0644'

##### `ignoreregexes`

Data type: `Array[String, 0]`

List of Python regular expressions that should prevent a log line from
being considered for banning. If a line matches regular expressions
contained in this parameter, they are ignored even though they would have
matched a failregex. Each item in the list is placed on its own line. Lines
starting with the second one are prepended with spaces so that the regular
expressions line up with the beginning of the first one.

Default value: []

##### `includes`

Data type: `Array[String, 0]`

List of files to include before considering the rest of the filter
definition. These files can declare variables used by the filter to set
default behaviours.

Default value: []

##### `includes_after`

Data type: `Array[String, 0]`

List of files to include after filter definition.

Default value: []

##### `additional_defs`

Data type: `Array[String, 0]`

List of arbitrary lines that should appear at the begining of the filter's
definition section, for anything that didn't fit in other parameters. Each
item in the list is output on its own line in the filter file. No syntax
checking is done.

Default value: []

### fail2ban::jail

fail2ban/manifests/jail.pp

- Copyright (C) 2014-2018 gabster@lelutin.ca

Jails are the top level of fail2ban configuration; what you'll be using most
often to setup protection of a service from bruteforce attempts or pesky
attack traffic. They rely on a filter to find out IPs that are doing
mischief, and then use an action to ban (and subsequently unban) IPs.

Most parameters of this defined type are used for overriding what has been
set in the global context in jail.conf/jail.local (see parameters to the
fail2ban class). They are not mandatory if you can reuse the global values.

* **See also**
https://github.com/fail2ban/fail2ban/blob/0.11/man/jail.conf.5
jail.conf(5)

#### Examples

##### creating simple jail for service

```puppet
fail2ban::jail { 'honeypot':
  findtime => 300,
  maxretry => 1,
  port     => 'all',
  logpath  => '/var/log/honeypot.log',
}
```

##### using a pre-defined jail

```puppet
$ssh_params = lookup('fail2ban::jail::sshd')
fail2ban::jail { 'sshd':
  * => $ssh_params,
}
```

##### overriding parameters from a pre-defined jail

```puppet
$ssh_extra_params  = {
  'bantime'  => 300,
  'findtime' => 200,
  'maxretry' => 3,
}
$ssh_params = lookup('fail2ban::jail::sshd') + $ssh_extra_params
fail2ban::jail { 'sshd':
  * => $ssh_params,
}
```

#### Parameters

The following parameters are available in the `fail2ban::jail` defined type.

##### `ensure`

Data type: `Enum['present','absent']`

Whether resources for the defined jail should be installed or removed.

Default value: 'present'

##### `enabled`

Data type: `Boolean`

Whether or not a jail is enabled. Setting this to false makes it possible
to keep configuration around for a certain jail but temporarily disable it.

Default value: `true`

##### `config_file_mode`

Data type: `String`

Permission mode given to the jail file created by this defined type.

Default value: '0644'

##### `port`

Data type: `Optional[Fail2ban::Port]`

Comma separated list of ports, port ranges or service names (as found in
/etc/services) that should get blocked by the ban action.

Default value: `undef`

##### `filter`

Data type: `Optional[String]`

Name of the filter to use for this jail. The default value for the filter
is usually to use a filter with the same name as the jail name (although
this could be changed by the filter parameter on the fail2ban class).

Default value: `undef`

##### `logpath`

Data type: `Optional[String]`

Absolute path to the log file against which regular expressions should be
verified to catch activity that you want to block.

Default value: `undef`

##### `protocol`

Data type: `Optional[Fail2ban::Protocol]`

Name of the protocol to ban using the action.

Default value: `undef`

##### `maxretry`

Data type: `Optional[Integer]`

Number of failregex matches during findtime after which an IP gets banned.

Default value: `undef`

##### `findtime`

Data type: `Optional[Integer]`

Time period in seconds during which maxretry number of matches will get an
IP banned.

Default value: `undef`

##### `ignorecommand`

Data type: `Optional[String]`

Command used to determine if an IP should found by a failregex be ignored.
This can be used to have a more complex and dynamic method of listing and
identifying IPs that should not get banned. It can be used also when
ignoreip is present.

Default value: `undef`

##### `action`

Data type: `Optional[String]`

Name of and parameters to the action that should be used to ban and unban
IPs when maxretry matches of failregex has happened for an IP during
findtime.

Default value: `undef`

##### `usedns`

Data type: `Optional[Fail2ban::Usedns]`

Whether or not to resolve DNS hostname of IPs that have been found by a
failregex.

Default value: `undef`

##### `banaction`

Data type: `Optional[String]`

Name of the action that is extrapolated in default action definitions, or
in the action param. This can let you override the action name but keep the
default parameters to the action.

Default value: `undef`

##### `bantime`

Data type: `Optional[Integer]`

Time period in seconds for which an IP is banned if maxretry matches of
failregex happen for the same IP during findtime.

Default value: `undef`

##### `ignoreip`

Data type: `Array[String, 0]`

List of IPs or CIDR prefixes to ignore when identifying matches of
failregex. The IPs that fit the descriptions in this parameter will never
get banned by the jail.

Default value: []

##### `backend`

Data type: `Optional[Fail2ban::Backend]`

Method used by fail2ban to obtain new log lines from the log file in
logpath.

Default value: `undef`

##### `additional_options`

Data type: `Hash[String, String]`

Hash of additional values that should be declared of the jail. Keys are the
value name and values are placed to the right of the "=". This can be used
to declare arbitrary values for filters or actions to use. No syntax
checking is done on the contents of this hash.

Default value: {}

